"{ Package: 'stx:goodies/sunit' }"

Object subclass:#TestSuite
	instanceVariableNames:'name tests resources'
	classVariableNames:''
	poolDictionaries:''
	category:'SUnit-Base'
!


!TestSuite methodsFor:'Accessing'!

addTest: aTest
	self tests add: aTest
!

addTests: aCollection 
	aCollection do: [:eachTest | self addTest: eachTest]
!

defaultResources
	^self tests 
		inject: Set new
		into: 
			[:coll :testCase | 
			coll
				addAll: testCase resources;
				yourself]
!

name
        ^ name ? 'a TestSuite'.
!

name:aString
        name := aString
!

resources
	resources isNil ifTrue: [resources := self defaultResources].
	^resources
!

resources: anObject
	resources := anObject
!

tests
	tests isNil ifTrue: [tests := OrderedCollection new].
	^tests
! !

!TestSuite methodsFor:'Dependencies'!

addDependentToHierachy: anObject
        self addDependent: anObject.
        self tests do: [:each | each addDependentToHierachy: anObject]

    "Modified: / 21.6.2000 / 10:13:35 / Sames"
!

removeDependentFromHierachy: anObject
        self removeDependent: anObject.
        self tests do: [:each | each removeDependentFromHierachy: anObject]

    "Modified: / 21.6.2000 / 10:13:27 / Sames"
! !

!TestSuite methodsFor:'Running'!

run
        | result |
        result := TestResult new.
        self areAllResourcesAvailable ifFalse: [^TestResult signalErrorWith: 'Resource could not be initialized'].
        [self run: result] ensure: [self resources do: [:each | each reset]].
        ^result
!

run: aResult 
        self tests do: 
                [:each | 
                self changed: each.
                each run: aResult]

    "Modified: / 21.6.2000 / 10:14:01 / Sames"
!

run: aResult afterEachDo:block2
        self tests do: 
                [:each | 
                self changed: each.
                each run: aResult.
                block2 value:each value:aResult
                ]

    "Modified: / 21.6.2000 / 10:14:01 / Sames"
! !

!TestSuite methodsFor:'Testing'!

areAllResourcesAvailable
	^self resources 
		inject: true
		into: [:total :each | each isAvailable & total]
! !

!TestSuite class methodsFor:'documentation'!

version
    ^ '$Header: /cvs/stx/stx/goodies/sunit/TestSuite.st,v 1.8 2001-12-13 22:06:26 cg Exp $'
! !
